@@ -9,8 +9,13 @@ print.model_spec <- function(x, ...) {
 #' @rdname add_on_exports
 #' @export
 print_model_spec <- function(x, cls = class(x)[1], desc = get_model_desc(cls), ...) {
+  if (!spec_is_loaded(spec = structure(x, class = cls))) {
+    prompt_missing_implementation(spec = structure(x, class = cls), prompt = cli::cli_inform)
+  }
 
-  cat(desc, " Model Specification (", x$mode, ")\n\n", sep = "")
+  mode <- switch(x$mode, unknown = "unknown mode", x$mode)
+
+  cat(desc, " Model Specification (", mode, ")\n\n", sep = "")
   model_printer(x, ...)
 
   if (is_printable_spec(x)) {
@@ -35,6 +40,7 @@ model_descs <- tibble::tribble(
   ~cls,                   ~desc,
   "auto_ml",              "Automatic Machine Learning",
   "bag_mars",             "Bagged MARS",
+  "bag_mlp",              "Bagged Neural Network",
   "bag_tree",             "Bagged Decision Tree",
   "bart",                 "BART",
   "boost_tree",           "Boosted Tree",
